@@ -36,6 +36,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <ykpers-version.h>
 
+#include <QUrl>
+#include <QDesktopServices>
+#include <QSignalMapper>
+
 AboutPage::AboutPage(QWidget *parent) :
         QWidget(parent),
         ui(new Ui::AboutPage)
@@ -56,17 +60,9 @@ AboutPage::AboutPage(QWidget *parent) :
 
     ui->libVersionLbl->setText(libVersion);
 
-    //Set build timestamp
-    QString buildTS = tr("%1 %2 %3").
-                      arg(ui->buildTimestampLbl->text()).
-                      arg(__DATE__).
-                      arg(__TIME__);
-
-    ui->buildTimestampLbl->setText(buildTS);
-
     //Set copyright
     QString copyright = tr("%1. %2.").
-                        arg(VER_LEGALCOPYRIGHT).
+                        arg(trUtf8(VER_LEGALCOPYRIGHT)).
                         arg(VER_LEGALTRADEMARKS1_STR);
 
     ui->copyrightLbl->setText(copyright);
@@ -151,5 +147,5 @@ void AboutPage::btn_pressed(int pageIndex) {
 }
 
 void AboutPage::on_supportBtn_clicked() {
-    QDesktopServices::openUrl(QUrl(SUPPORT_LINK));
+    QDesktopServices::openUrl(QUrl(tr(SUPPORT_LINK)));
 }
