@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2013 Yubico AB.  All rights reserved.
+Copyright (C) 2013-2014 Yubico AB.  All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are
@@ -63,7 +63,8 @@ private slots:
     void on_configProtectionCombo_currentIndexChanged(int index);
     void on_currentAccessCodeTxt_editingFinished();
     void on_newAccessCodeTxt_editingFinished();
-    void helpBtn_pressed(int helpIndex);
+signals:
+    void showHelp(int helpIndex);
 };
 
 #endif // YUBIACCBOX_H
